@@ -7,8 +7,8 @@ class Duckduckgo:
     Duckduckgo API Retriever
     """
     def __init__(self, query, query_domains=None):
-        check_pkg('duckduckgo_search')
-        from duckduckgo_search import DDGS
+        check_pkg('ddgs')
+        from ddgs import DDGS
         self.ddg = DDGS()
         self.query = query
         self.query_domains = query_domains or None
@@ -26,4 +26,4 @@ class Duckduckgo:
         except Exception as e:
             print(f"Error: {e}. Failed fetching sources. Resulting in empty response.")
             search_response = []
-        return search_response
\ No newline at end of file
+        return search_response
